apply_sprintf_substitutions

Function apply_sprintf_substitutions 

fn apply_sprintf_substitutions(
    cx: JSContext,
    messages: &[HandleValue<'_>],
) -> (String, usize)
Apply sprintf-style substitutions to console format arguments per the WHATWG Console spec.

If the first argument is a string, it is treated as a format string where %s, %d, %i, %f, %o, %O, and %c are replaced by subsequent arguments. Returns the formatted string and the index of the first argument that was not consumed by a substitution.

https://console.spec.whatwg.org/#formatter